@@ -663,14 +663,14 @@ def add_certification(hash_str: str, cert_num: str, expire_date: int, version: s
                       address: str, contract_address: str, pk: str):
     client = Web3(Web3.HTTPProvider(node_url))
     contract_instance = client.eth.contract(address=contract_address, abi=abi)
-    nonce = client.eth.getTransactionCount(client.toChecksumAddress(address))
+    nonce = client.eth.get_transaction_count(client.toChecksumAddress(address))
 
     try:
         func = contract_instance.functions.addCertification(hash_str, cert_num, expire_date, version, desc)
         tx = func.buildTransaction(
             {'from': address, 'gasPrice': client.toWei('1000', 'gwei'), 'nonce': nonce, 'gas': DEFAULT_GAS_LIMIT})
-        signed = client.eth.account.signTransaction(tx, pk)
-        tx_hash = client.eth.sendRawTransaction(signed.rawTransaction)
+        signed = client.eth.account.sign_transaction(tx, pk)
+        tx_hash = client.eth.send_raw_transaction(signed.rawTransaction)
         tx_res = client.eth.wait_for_transaction_receipt(tx_hash)
         if tx_res.status == 1:
             return client.toHex(tx_hash), None
@@ -683,14 +683,14 @@ def add_certification(hash_str: str, cert_num: str, expire_date: int, version: s
 def revoke_certification(hash_str: str, revoker_name: str, node_url: str, contract_address: str, address: str, pk: str):
     client = Web3(Web3.HTTPProvider(node_url))
     contract_instance = client.eth.contract(address=contract_address, abi=abi)
-    nonce = client.eth.getTransactionCount(client.toChecksumAddress(address))
+    nonce = client.eth.get_transaction_count(client.toChecksumAddress(address))
 
     try:
         func = contract_instance.functions.revoke(hash_str, revoker_name)
         tx = func.buildTransaction(
             {'from': address, 'gasPrice': client.toWei('1000', 'gwei'), 'nonce': nonce, 'gas': DEFAULT_GAS_LIMIT})
-        signed = client.eth.account.signTransaction(tx, pk)
-        tx_hash = client.eth.sendRawTransaction(signed.rawTransaction)
+        signed = client.eth.account.sign_transaction(tx, pk)
+        tx_hash = client.eth.send_raw_transaction(signed.rawTransaction)
         tx_res = client.eth.wait_for_transaction_receipt(tx_hash)
         if tx_res.status == 1:
             return client.toHex(tx_hash), None
@@ -706,14 +706,14 @@ def revoke_certification_by_id(cert_id: int, revoker_name: str, node_url: str, c
     # f = open('abi.json')
     # abi = json.load(f)
     contract_instance = client.eth.contract(address=contract_address, abi=abi)
-    nonce = client.eth.getTransactionCount(client.toChecksumAddress(address))
+    nonce = client.eth.get_transaction_count(client.toChecksumAddress(address))
 
     try:
         func = contract_instance.functions.revokeById(cert_id, revoker_name)
         tx = func.buildTransaction(
             {'from': address, 'gasPrice': client.toWei('1000', 'gwei'), 'nonce': nonce, 'gas': DEFAULT_GAS_LIMIT})
-        signed = client.eth.account.signTransaction(tx, pk)
-        tx_hash = client.eth.sendRawTransaction(signed.rawTransaction)
+        signed = client.eth.account.sign_transaction(tx, pk)
+        tx_hash = client.eth.send_raw_transaction(signed.rawTransaction)
         tx_res = client.eth.wait_for_transaction_receipt(tx_hash)
         if tx_res.status == 1:
             return client.toHex(tx_hash), None
@@ -728,14 +728,14 @@ def charge_credit(address: str, credit: int, owner_address, owner_pk, node_url,
     # f = open('abi.json')
     # abi = json.load(f)
     contract_instance = client.eth.contract(address=contract_address, abi=abi)
-    nonce = client.eth.getTransactionCount(client.toChecksumAddress(owner_address))
+    nonce = client.eth.get_transaction_count(client.toChecksumAddress(owner_address))
 
     try:
         func = contract_instance.functions.chargeCredit(client.toChecksumAddress(address), credit)
         tx = func.buildTransaction(
             {'from': address, 'gasPrice': client.toWei('1000', 'gwei'), 'nonce': nonce, 'gas': DEFAULT_GAS_LIMIT})
-        signed = client.eth.account.signTransaction(tx, owner_pk)
-        tx_hash = client.eth.sendRawTransaction(signed.rawTransaction)
+        signed = client.eth.account.sign_transaction(tx, owner_pk)
+        tx_hash = client.eth.send_raw_transaction(signed.rawTransaction)
         tx_res = client.eth.wait_for_transaction_receipt(tx_hash)
         if tx_res.status == 1:
             return client.toHex(tx_hash), None
