@@ -37,11 +37,11 @@ def issue(src_path: str,
     # calc hash
     hash_str = Utils.calc_hash(dest_path)
 
-    (tx, proof) = issue_by_hash(hash_str, cert_num, address, expire_date, description, private_key, key_store,
-                                passphrase, certify_address, node_url, is_testnet)
+    (tx, proof), error = issue_by_hash(hash_str, cert_num, address, expire_date, description, private_key, key_store,
+                                       passphrase, certify_address, node_url, is_testnet)
     add_metadata(dest_path, dest_path, chainpoint_proof=proof)
 
-    return tx, None
+    return tx, error
 
 
 def issue_by_hash(hash_str, cert_num, address: str,
